@@ -1,7 +1,13 @@
 from __future__ import absolute_import
 from __future__ import with_statement
 
-from celery.utils.compat import OrderedDict
+from celery.events.state import Task as _Task
+
+try:
+    from collections import OrderedDict
+except ImportError:
+    # celery <3.2 provides this
+    from celery.utils.compat import OrderedDict
 
 
 class BaseModel(object):
@@ -83,21 +89,21 @@ class WorkerModel(BaseModel):
 
 class TaskModel(BaseModel):
     def __init__(self, app, task_id):
-        super(TaskModel, self).__init__(app)
+        self.uuid = task_id
 
-        task = app.events.state.tasks[task_id]
+    if hasattr(_Task, '_fields'):  # Old version
+        @classmethod
+        def get_task_by_id(cls, app, task_id):
+            return app.events.state.tasks.get(task_id)
+    else:
+        _fields = _Task._defaults.keys()
 
-        self._fields = task._defaults.keys()
-        for name in self._fields:
-            if hasattr(task, name):
-                setattr(self, name, getattr(task, name))
-
-    @classmethod
-    def get_task_by_id(cls, app, task_id):
-        try:
-            return TaskModel(app, task_id)
-        except KeyError:
-            return None
+        @classmethod
+        def get_task_by_id(cls, app, task_id):
+            task = app.events.state.tasks.get(task_id)
+            if task is not None:
+                task._fields = cls._fields
+            return task
 
     @classmethod
     def iter_tasks(cls, app, limit=None, type=None, worker=None, state=None):
@@ -106,7 +112,7 @@ class TaskModel(BaseModel):
         for uuid, task in events_state.tasks_by_timestamp():
             if type and task.name != type:
                 continue
-            if worker and task.worker.hostname != worker:
+            if worker and task.worker and task.worker.hostname != worker:
                 continue
             if state and task.state != state:
                 continue
